@@ -702,16 +702,43 @@ trash_item_callback (GtkWidget *item, gpointer user_data)
 }
 
 
+static void
+on_detached_clicked_cb (BjbMainToolbar *self)
+{
+  BijiNoteObj *note;
+
+  note = bjb_window_base_get_note (BJB_WINDOW_BASE (self->priv->window));
+  bjb_window_base_switch_to (BJB_WINDOW_BASE (self->priv->window),
+                             BJB_WINDOW_BASE_MAIN_VIEW);
+  bijiben_new_window_for_note (g_application_get_default (), note);
+}
+
+
 GtkWidget *
 bjb_note_menu_new (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
   GtkWidget             *result, *item;
   BijiWebkitEditor      *editor;
+  gboolean               detached;
 
   result = gtk_menu_new();
   editor = BIJI_WEBKIT_EDITOR (biji_note_obj_get_editor (priv->note));
 
+  /* Detach and separator */
+  detached = bjb_window_base_is_detached (BJB_WINDOW_BASE (self->priv->window));
+  if (detached == FALSE)
+  {
+    item = gtk_menu_item_new_with_label (_("Open in another window"));
+    gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
+    g_signal_connect_swapped (item, "activate",
+                              G_CALLBACK (on_detached_clicked_cb), self);
+
+
+    item = gtk_separator_menu_item_new ();
+    gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
+  }
+
   /* Undo Redo separator */
   item = gtk_menu_item_new_with_label (_("Undo"));
   gtk_menu_shell_append (GTK_MENU_SHELL (result), item);
@@ -784,12 +811,13 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   BijiItem *item;
   GtkWidget *share_image;
   GtkWidget *menu_image;
-  gboolean rtl;
+  gboolean rtl, detached;
 
   priv->note = bjb_window_base_get_note (BJB_WINDOW_BASE (self->priv->window));
   item = BIJI_ITEM (priv->note);
 
   rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
+  detached = bjb_window_base_is_detached (BJB_WINDOW_BASE (self->priv->window));
 
   if (!priv->note) /* no reason this would happen */
     return;
@@ -797,15 +825,18 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   settings = bjb_app_get_settings (g_application_get_default());
 
   /* Go to main view basically means closing note */
-  priv->back = gtk_button_new_from_icon_name (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
-                                              GTK_ICON_SIZE_MENU);
-  gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
-  gtk_header_bar_pack_start (bar, priv->back);
+  if (!detached)
+  {
+    priv->back = gtk_button_new_from_icon_name (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
+                                                GTK_ICON_SIZE_MENU);
+    gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
+    gtk_header_bar_pack_start (bar, priv->back);
 
-  g_signal_connect_swapped (priv->back, "clicked",
-                            G_CALLBACK (just_switch_to_main_view), self);
-  gtk_widget_add_accelerator (priv->back, "activate", self->priv->accel,
-                              GDK_KEY_w, GDK_CONTROL_MASK, GTK_ACCEL_MASK);
+    g_signal_connect_swapped (priv->back, "clicked",
+                              G_CALLBACK (just_switch_to_main_view), self);
+    gtk_widget_add_accelerator (priv->back, "activate", self->priv->accel,
+                                GDK_KEY_w, GDK_CONTROL_MASK, GTK_ACCEL_MASK);
+  }
 
   /* Note Title */
   on_note_renamed (item, self);
