@@ -14,12 +14,20 @@
 #include "bjb-note-view.h"
 
 
-#define BJB_WIDTH 810
-#define BJB_HEIGHT 600
 #define BIJIBEN_MAIN_WIN_TITLE N_("Notes")
 
 #define BJB_DEFAULT_FONT "Serif 10"
 
+
+enum {
+  PROP_0,
+  PROP_NOTE,
+  NUM_PROPERTIES
+};
+
+static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
+
+
 enum {
   BJB_WIN_BASE_VIEW_CHANGED,
   BJB_WIN_BASE_ACTIVATED,
@@ -31,7 +39,7 @@ static guint bjb_win_base_signals [BJB_WIN_BASE_SIGNALS] = { 0 };
 
 struct _BjbWindowBasePriv
 {
-  GtkApplication       *app ;
+  BjbSettings          *settings;
   BjbController        *controller;
   gchar                *entry; // FIXME, remove this
 
@@ -51,6 +59,7 @@ struct _BjbWindowBasePriv
 
   /* when a note is opened */
   BijiNoteObj          *note;
+  gboolean              detached; // detached note
   GtkWidget            *note_overlay;
 
 
@@ -85,6 +94,55 @@ bjb_window_base_finalize (GObject *object)
   G_OBJECT_CLASS (bjb_window_base_parent_class)->finalize (object);
 }
 
+
+
+
+static void
+bjb_window_base_get_property (GObject  *object,
+                              guint     property_id,
+                              GValue   *value,
+                              GParamSpec *pspec)
+{
+  BjbWindowBase *self = BJB_WINDOW_BASE (object);
+
+  switch (property_id)
+  {
+  case PROP_NOTE:
+    g_value_set_object (value, self->priv->note);
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
+  }
+}
+
+
+static void
+bjb_window_base_set_property (GObject  *object,
+                              guint     property_id,
+                              const GValue *value,
+                              GParamSpec *pspec)
+{
+  BjbWindowBase *self = BJB_WINDOW_BASE (object);
+
+  switch (property_id)
+  {
+  case PROP_NOTE:
+    self->priv->note = g_value_get_object (value);
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
+  }
+}
+
+
+
+
+
+
+
+
 /* Just disconnect to avoid crash, the finalize does the real
  * job */
 static void
@@ -93,6 +151,66 @@ bjb_window_base_destroy (gpointer a, BjbWindowBase * self)
   bjb_controller_disconnect (self->priv->controller);
 }
 
+
+static gboolean
+bjb_application_window_state_changed (GtkWidget *widget,
+                                      GdkEvent  *event,
+                                      gpointer   user_data)
+{
+  GSettings *settings;
+  GdkWindowState state;
+  gboolean maximized;
+
+  settings = user_data;
+  state = gdk_window_get_state (gtk_widget_get_window (widget));
+  maximized = state & GDK_WINDOW_STATE_MAXIMIZED;
+
+  g_settings_set_boolean (settings, "window-maximized", maximized);
+
+  return FALSE;
+}
+
+
+static gboolean
+bjb_application_window_configured (GtkWidget *widget,
+                                   GdkEvent  *event,
+                                   gpointer   user_data)
+{
+  BjbWindowBase *win;
+  GSettings *settings;
+  GVariant *variant;
+  GdkWindowState state;
+  gint32 size[2];
+  gint32 position[2];
+
+  win = BJB_WINDOW_BASE (user_data);
+  settings = G_SETTINGS (win->priv->settings);
+  state = gdk_window_get_state (gtk_widget_get_window (widget));
+  if (state & GDK_WINDOW_STATE_MAXIMIZED)
+    return FALSE;
+
+  gtk_window_get_size (GTK_WINDOW (win),
+                       (gint *) &size[0],
+                       (gint *) &size[1]);
+  variant = g_variant_new_fixed_array (G_VARIANT_TYPE_INT32,
+                                       size, 2,
+                                       sizeof (size[0]));
+  g_settings_set_value (settings, "window-size", variant);
+
+  gtk_window_get_position (GTK_WINDOW (win),
+                           (gint *) &position[0],
+                           (gint *) &position[1]);
+  variant = g_variant_new_fixed_array (G_VARIANT_TYPE_INT32,
+                                       position, 2,
+                                       sizeof (position[0]));
+  g_settings_set_value (settings, "window-position", variant);
+
+  return FALSE;
+}
+
+
+
+
 /* Gobj */
 static void
 bjb_window_base_constructed (GObject *obj)
@@ -104,16 +222,42 @@ bjb_window_base_constructed (GObject *obj)
   GList *icons = NULL;
   GdkPixbuf *bjb ;
   GError *error = NULL;
+  gboolean maximized;
+  const gint32 *position;
+  const gint32 *size;
+  gsize n_elements;
+  GVariant *variant;
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
   priv = self->priv;
-  priv->note = NULL;
+  priv->settings = bjb_app_get_settings ((gpointer) g_application_get_default ());
+
+
+
 
-  gtk_window_set_default_size (GTK_WINDOW (self), BJB_WIDTH, BJB_HEIGHT);
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
   gtk_window_set_title (GTK_WINDOW (self), _(BIJIBEN_MAIN_WIN_TITLE));
 
+  variant = g_settings_get_value (G_SETTINGS (priv->settings), "window-size");
+  size = g_variant_get_fixed_array (variant, &n_elements, sizeof (gint32));
+  if (n_elements == 2)
+    gtk_window_set_default_size (GTK_WINDOW (self), size[0], size[1]);
+
+  g_variant_unref (variant);
+
+  variant = g_settings_get_value (G_SETTINGS (priv->settings), "window-position");
+  position = g_variant_get_fixed_array (variant, &n_elements, sizeof (gint32));
+  if (n_elements == 2)
+    gtk_window_move (GTK_WINDOW (self), position[0], position[1]);
+
+  g_variant_unref (variant);
+
+  maximized = g_settings_get_boolean (G_SETTINGS (priv->settings), "window-maximized");
+  if (maximized)
+    gtk_window_maximize (GTK_WINDOW (self));
+
+
   /* Icon for window. TODO - Should be BjbApp */
   icons_path = bijiben_get_bijiben_dir ();
   full_path = g_build_filename (icons_path,
@@ -171,9 +315,33 @@ bjb_window_base_constructed (GObject *obj)
 
   gtk_stack_add_named (priv->stack, GTK_WIDGET (priv->view), "main-view");
 
-  g_signal_connect (
-    GTK_WIDGET (self), "destroy", G_CALLBACK (bjb_window_base_destroy), self);
+  g_signal_connect (GTK_WIDGET (self),
+                    "destroy",
+                    G_CALLBACK (bjb_window_base_destroy),
+                    self);
 
+  g_signal_connect (self,
+                    "window-state-event",
+                    G_CALLBACK (bjb_application_window_state_changed),
+                    priv->settings);
+
+  g_signal_connect (self,
+                    "configure-event",
+                    G_CALLBACK (bjb_application_window_configured),
+                    self);
+
+  /* If a note is requested at creation, show it
+   * This is a specific type of window not associated with any view */
+  if (priv->note == NULL)
+  {
+    bjb_window_base_switch_to (self, BJB_WINDOW_BASE_MAIN_VIEW);
+  }
+
+  else
+  {
+    priv->detached = TRUE;
+    bjb_window_base_switch_to_item (self, BIJI_ITEM (priv->note));
+  }
 }
 
 static void
@@ -187,6 +355,8 @@ bjb_window_base_init (BjbWindowBase *self)
 
   /* Default window has no note opened */
   priv->note_view = NULL;
+  priv->note = NULL;
+  priv->detached = FALSE;
 
   priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (self), priv->vbox);
@@ -197,9 +367,12 @@ bjb_window_base_class_init (BjbWindowBaseClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
+
   gobject_class->constructed = bjb_window_base_constructed;
   gobject_class->constructor = bjb_window_base_constructor;
   gobject_class->finalize = bjb_window_base_finalize ;
+  gobject_class->get_property = bjb_window_base_get_property;
+  gobject_class->set_property = bjb_window_base_set_property;
 
   g_type_class_add_private (klass, sizeof (BjbWindowBasePriv));
 
@@ -223,14 +396,26 @@ bjb_window_base_class_init (BjbWindowBaseClass *klass)
                                                     G_TYPE_NONE,
                                                     1,
                                                     G_TYPE_BOOLEAN);
+
+  properties[PROP_NOTE] = g_param_spec_object ("note",
+                                               "NoteObj",
+                                               "Currently opened note",
+                                               BIJI_TYPE_NOTE_OBJ,
+                                               G_PARAM_READWRITE |
+                                               G_PARAM_CONSTRUCT |
+                                               G_PARAM_STATIC_STRINGS);
+
+  g_object_class_install_properties (gobject_class, NUM_PROPERTIES, properties);
+
 }
 
 
 GtkWindow *
-bjb_window_base_new(void)
+bjb_window_base_new                    (BijiNoteObj *note)
 {
   return g_object_new (BJB_TYPE_WINDOW_BASE,
                        "application", g_application_get_default(),
+                       "note", note,
                        NULL);
 }
 
@@ -459,3 +644,10 @@ bjb_window_base_set_active (BjbWindowBase *self, gboolean active)
                    available);
   }
 }
+
+
+gboolean
+bjb_window_base_is_detached (BjbWindowBase *self)
+{
+  return self->priv->detached;
+}
